<?php

$labels = array();
$labels['keyboard_shortcuts'] = 'Keyboard shortcuts';
$labels['show'] = 'Show';
$labels['help'] = 'Help';
$labels['selectallvisiblemessages'] = 'Select all visible messages';
$labels['markallvisiblemessagesasread'] = 'Mark all visible messages as read';
$labels['title'] = 'Shortcuts';

?>
