<?php

$labels = array();
$labels['keyboard_shortcuts'] = 'Sneltoetsen';
$labels['show'] = 'Show';
$labels['help'] = 'Help';
$labels['selectallvisiblemessages'] = 'Selecteer alle berichten op deze pagina';
$labels['markallvisiblemessagesasread'] = 'Markeer alle berichten op deze pagina als gelezen';
$labels['title'] = 'Sneltoetsen';

?>
