<?php

$labels = array();
$labels['keyboard_shortcuts'] = 'Tastatur Shortcuts';
$labels['show'] = 'Anzeigen';
$labels['help'] = 'Hilfe';
$labels['selectallvisiblemessages'] = 'Alle Nachrichten auswählen';
$labels['markallvisiblemessagesasread'] = 'Alle Nachrichten als gelesen markieren';
$labels['compose'] = 'Neue Nachricht verfassen';

?>
