<?php

$labels = array();
$labels['keyboard_shortcuts'] = 'Kortkommandon';
$labels['show'] = 'Visa';
$labels['help'] = 'Hj&auml;lp';
$labels['selectallvisiblemessages'] = 'Markera alla synliga meddelanden';
$labels['markallvisiblemessagesasread'] = 'Markera alla synliga meddelanden som l&auml;sta';

?>
