<?php

$labels = array();
$labels['keyboard_shortcuts'] = '快速鍵';
$labels['show'] = '顯示';
$labels['help'] = '說明';
$labels['selectallvisiblemessages'] = '選擇所有此頁的訊息';
$labels['markallvisiblemessagesasread'] = '標示所有此頁訊息以閱讀';
$labels['title'] = '快速鍵';

?>
