<?php

$labels = array();
$labels['keyboard_shortcuts'] = 'Горячие клавиши';
$labels['show'] = 'Показать';
$labels['help'] = 'Помощь';
$labels['selectallvisiblemessages'] = 'Выделить все видимые сообщения';
$labels['markallvisiblemessagesasread'] = 'Пометить все видимые сообщения как прочитанные';
$labels['title'] = 'Горячие клавиши';

?>
