<?php

/*
+-----------------------------------------------------------------------+
| language/cs_CZ/labels.inc                                             |
|                                                                       |
| Language file of the RoundCube Webmail client                         |
| Copyright (C) 2008-2009, RoundQube Dev. - Switzerland                 |
| Licensed under the GNU GPL                                            |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Ales Pospichal <ales@pospichalales.info>                      |
+-----------------------------------------------------------------------+

*/

$labels = array();
$labels['keyboard_shortcuts'] = 'Klávesnicové zkratky';
$labels['show'] = 'Zobrazit';
$labels['help'] = 'Nápověda';
$labels['selectallvisiblemessages'] = 'Vybrat všechny viditelné zprávy';
$labels['markallvisiblemessagesasread'] = 'Označit všechny viditelné zprávy jako přečtené';

?>
