<?php
/* Author: DZIOBAK */

$labels = array();
$labels['keyboard_shortcuts'] = 'Skróty klawiszowe';
$labels['show'] = 'Pokaż';
$labels['help'] = 'Pomoc';
$labels['selectallvisiblemessages'] = 'Zaznacz wszystkie widoczne wiadomości';
$labels['markallvisiblemessagesasread'] = 'Zaznacz wszystkie widoczne wiadomości jako przeczytane';

?>
